Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGitLab Bot <gitlab-bot@gitlab.com>2021-05-19 18:44:42 +0300
committerGitLab Bot <gitlab-bot@gitlab.com>2021-05-19 18:44:42 +0300
commit4555e1b21c365ed8303ffb7a3325d773c9b8bf31 (patch)
tree5423a1c7516cffe36384133ade12572cf709398d /spec/spec_helper.rb
parente570267f2f6b326480d284e0164a6464ba4081bc (diff)
Add latest changes from gitlab-org/gitlab@13-12-stable-eev13.12.0-rc42
Diffstat (limited to 'spec/spec_helper.rb')
-rw-r--r--spec/spec_helper.rb24
1 files changed, 22 insertions, 2 deletions
diff --git a/spec/spec_helper.rb b/spec/spec_helper.rb
index 4179e6f7e91..c59daa6c919 100644
--- a/spec/spec_helper.rb
+++ b/spec/spec_helper.rb
@@ -253,6 +253,9 @@ RSpec.configure do |config|
# tests, until we introduce it in user settings
stub_feature_flags(forti_token_cloud: false)
+ # This feature flag is by default disabled and used in disaster recovery mode
+ stub_feature_flags(ci_queueing_disaster_recovery: false)
+
enable_rugged = example.metadata[:enable_rugged].present?
# Disable Rugged features by default
@@ -265,16 +268,33 @@ RSpec.configure do |config|
stub_feature_flags(file_identifier_hash: false)
stub_feature_flags(unified_diff_components: false)
+ stub_feature_flags(diffs_virtual_scrolling: false)
- # The following `vue_issues_list` stub can be removed once the
- # Vue issues page has feature parity with the current Haml page
+ # The following `vue_issues_list`/`vue_issuables_list` stubs can be removed
+ # once the Vue issues page has feature parity with the current Haml page
stub_feature_flags(vue_issues_list: false)
+ stub_feature_flags(vue_issuables_list: false)
# Disable `refactor_blob_viewer` as we refactor
# the blob viewer. See the follwing epic for more:
# https://gitlab.com/groups/gitlab-org/-/epics/5531
stub_feature_flags(refactor_blob_viewer: false)
+ # Disable `main_branch_over_master` as we migrate
+ # from `master` to `main` accross our codebase.
+ # It's done in order to preserve the concistency in tests
+ # As we're ready to change `master` usages to `main`, let's enable it
+ stub_feature_flags(main_branch_over_master: false)
+
+ # Selectively disable by actor https://docs.gitlab.com/ee/development/feature_flags/#selectively-disable-by-actor
+ stub_feature_flags(remove_description_html_in_release_api_override: false)
+
+ # Disable issue respositioning to avoid heavy load on database when importing big projects.
+ # This is only turned on when app is handling heavy project imports.
+ # Can be removed when we find a better way to deal with the problem.
+ # For more information check https://gitlab.com/gitlab-com/gl-infra/production/-/issues/4321
+ stub_feature_flags(block_issue_repositioning: false)
+
allow(Gitlab::GitalyClient).to receive(:can_use_disk?).and_return(enable_rugged)
else
unstub_all_feature_flags